==> nextcloud-14.0.13.zip: nextcloud/apps/theming/l10n/af.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laai voorskou…",
    "Saved" : "Bewaar",
    "Admin" : "Admin",
    "a safe home for all your data" : "’n veilige tuiste vir al u data",
    "Name cannot be empty" : "Naam kan nie leeg wees nie",
    "The given name is too long" : "Die gegewe naam is te lank",
    "The given web address is too long" : "Die gegewe webadres is te lank",
    "The given legal notice address is too long" : "Die gegewe regskennisgewingsadres is te lank",
    "The given privacy policy address is too long" : "Die gegewe privaatheidsbeleidadres is te lank",
    "The given slogan is too long" : "Gegewe slagspreuk is te lank",
    "The given color is invalid" : "Die gegewe kleur is ongeldig",
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "No file uploaded" : "Geen lêer opgelaai",
    "Unsupported image type" : "Onondersteunde beeldtipe",
    "Legal notice" : "Regskennisgewing",
    "Privacy policy" : "Privaatheidsbeleid",
    "Adjust the Nextcloud theme" : "Pas die Nextcloud-tema aan",
    "Name" : "Naam",
    "Reset to default" : "Herstel na verstek",
    "Web link" : "Webskakel",
    "Slogan" : "Slagspreuk",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Laai nuwe logo op",
    "Login image" : "Aantekenbeeld",
    "Upload new login background" : "Laai nuwe aantekenagtergrond op",
    "Remove background image" : "Verwyder agtergrondbeeld",
    "Advanced options" : "Gevorderde opsies",
    "Legal notice link" : "Regskennisgewingskakel",
    "Privacy policy link" : "Privaatheidsbeleidskakel"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0.zip: nextcloud/apps/theming/l10n/af.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laai voorskou…",
    "Saved" : "Bewaar",
    "Admin" : "Admin",
    "a safe home for all your data" : "’n veilige tuiste vir al u data",
    "The given name is too long" : "Die gegewe naam is te lank",
    "The given web address is too long" : "Die gegewe webadres is te lank",
    "The given slogan is too long" : "Gegewe slagspreuk is te lank",
    "The given color is invalid" : "Die gegewe kleur is ongeldig",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "No file uploaded" : "Geen lêer opgelaai",
    "Unsupported image type" : "Onondersteunde beeldtipe",
    "Name" : "Naam",
    "Reset to default" : "Herstel na verstek",
    "Slogan" : "Slagspreuk",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Laai nuwe logo op",
    "Login image" : "Aantekenbeeld",
    "Upload new login background" : "Laai nuwe aantekenagtergrond op",
    "Remove background image" : "Verwyder agtergrondbeeld",
    "There is no error, the file uploaded with success" : "Geen fout is teëgekom nie, die lêer is met suksesvol opgelaai",
    "The uploaded file was only partially uploaded" : "Die opgelaaide lêer is slegs gedeeltelik opgelaai",
    "You are already using a custom theme" : "U gebruik reeds ’n pasgemaakte tema",
    "Web address https://…" : "Webadres https://…"
},
"nplurals=2; plural=(n != 1);");
